[pve-devel] [PATCH pve-ha-manager] check_active_workers: fix typo /uuid/uid/

Thomas Lamprecht t.lamprecht at proxmox.com
Mon Dec 21 10:12:47 CET 2015


This typo caused a bug where resource_command_finished was never
called as $w->{uuid} is not existing and thus always undefined.
Use the correct $w->{uid} instead.

Also fix a comment where used 'uuid' to avoid confusion.

Signed-off-by: Thomas Lamprecht <t.lamprecht at proxmox.com>
---
 src/PVE/HA/LRM.pm | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/PVE/HA/LRM.pm b/src/PVE/HA/LRM.pm
index dd735d1..1fe5f67 100644
--- a/src/PVE/HA/LRM.pm
+++ b/src/PVE/HA/LRM.pm
@@ -64,7 +64,7 @@ sub shutdown_request {
 	    my $sd = $ss->{$sid};
 	    next if !$sd->{node};
 	    next if $sd->{node} ne $nodename;
 	    # Note: use undef uuid to mark shutdown/stop jobs
 	    $self->queue_resource_command($sid, undef, 'request_stop');
 	}
 
@@ -472,7 +472,7 @@ sub check_active_workers {
 	    # check status
 	    my $waitpid = waitpid($pid, WNOHANG);
 	    if (defined($waitpid) && ($waitpid == $pid)) {
-		if (defined($w->{uuid})) {
+		if (defined($w->{uid})) {
 		    $self->resource_command_finished($sid, $w->{uid}, $?);
 		} else {
 		    $self->stop_command_finished($sid, $?);
@@ -64,7 +64,7 @@ sub shutdown_request {
 	    next if !$sd->{node};
 	    next if $sd->{node} ne $nodename;
-	    # Note: use undef uuid to mark shutdown/stop jobs
+	    # Note: use undef uid to mark shutdown/stop jobs
 	    $self->queue_resource_command($sid, undef, 'request_stop');
 	}
-- 
2.1.4





More information about the pve-devel mailing list